0.9.9 API documentation: integer.hpp Source File

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

gtx/integer.hpp
Go to the documentation of this file.
1
13 #pragma once
14
15 // Dependency:
16 #include "../glm.hpp"
17 #include "../gtc/integer.hpp"
18
19 #if GLM_MESSAGES == GLM_ENABLE && !defined(GLM_EXT_INCLUDED)
20 # ifndef GLM_ENABLE_EXPERIMENTAL
21 # pragma message("GLM: GLM_GTX_integer is an experimental extension and may change in the future. Use #define GLM_ENABLE_EXPERIMENTAL before including it, if you really want to use it.")
22 # else
23 # pragma message("GLM: GLM_GTX_integer extension included")
24 # endif
25 #endif
26
27 namespace glm
28 {
31
34 GLM_FUNC_DECL int pow(int x, uint y);
35
38 GLM_FUNC_DECL int sqrt(int x);
39
42 GLM_FUNC_DECL unsigned int floor_log2(unsigned int x);
43
46 GLM_FUNC_DECL int mod(int x, int y);
47
50 template<typename genType>
51 GLM_FUNC_DECL genType factorial(genType const& x);
52
55 typedef signed int sint;
56
59 GLM_FUNC_DECL uint pow(uint x, uint y);
60
63 GLM_FUNC_DECL uint sqrt(uint x);
64
67 GLM_FUNC_DECL uint mod(uint x, uint y);
68
71 GLM_FUNC_DECL uint nlz(uint x);
72
74 }//namespace glm
75
76 #include "integer.inl"
glm::nlz
GLM_FUNC_DECL uint nlz(uint x)
Returns the number of leading zeros.
glm::mod
GLM_FUNC_DECL uint mod(uint x, uint y)
Modulus.
glm::floor_log2
GLM_FUNC_DECL unsigned int floor_log2(unsigned int x)
Returns the floor log2 of x.
glm::sint
signed int sint
32bit signed integer.
Definition: gtx/integer.hpp:55
glm::factorial
GLM_FUNC_DECL genType factorial(genType const &x)
Return the factorial value of a number (!12 max, integer only) From GLM_GTX_integer extension...
glm::pow
GLM_FUNC_DECL uint pow(uint x, uint y)
Returns x raised to the y power.
glm::sqrt
GLM_FUNC_DECL uint sqrt(uint x)
Returns the positive square root of x.
glm
Definition: common.hpp:20